==> yawp-1.21.1-fabric-0.6.1-beta1-sources.jar: de/z0rdak/yawp/mixin/flag/BowItemMixin.java <==

package de.z0rdak.yawp.mixin.flag;

import de.z0rdak.yawp.api.FlagEvaluator;
import de.z0rdak.yawp.api.events.region.FlagCheckEvent;
import de.z0rdak.yawp.platform.Services;
import net.minecraft.class_1309;
import net.minecraft.class_1657;
import net.minecraft.class_1753;
import net.minecraft.class_1799;
import net.minecraft.class_1937;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfo;

import static de.z0rdak.yawp.api.MessageSender.sendFlagMsg;
import static de.z0rdak.yawp.core.flag.RegionFlag.FIRE_BOW;
import static de.z0rdak.yawp.handler.HandlerUtil.getDimKey;
import static de.z0rdak.yawp.handler.HandlerUtil.isServerSide;

@Mixin({class_1753.class})
public abstract class BowItemMixin {
    
    @Inject(method = "releaseUsing", at = @At(value = "INVOKE", target = "Lnet/minecraft/world/item/BowItem;getPowerForTime(I)F"), allow = 1, cancellable = true)
    void onLooseArrow(class_1799 stack, class_1937 level, class_1309 entityLiving, int timeLeft, CallbackInfo ci) {
        class_1657 player = (class_1657) entityLiving;
        if (isServerSide(player.method_37908())) {
            FlagCheckEvent checkEvent = new FlagCheckEvent(player.method_24515(), FIRE_BOW, getDimKey(player), player);
            if (Services.EVENT.post(checkEvent)) {
                return;
            }
            FlagEvaluator.processCheck(checkEvent, denyResult -> {
                ci.cancel();
                sendFlagMsg(denyResult);
            });
        }
    }
}

==> yawp-1.21.7-fabric-0.6.2-beta1-sources.jar: de/z0rdak/yawp/mixin/flag/BowItemMixin.java <==

package de.z0rdak.yawp.mixin.flag;

import de.z0rdak.yawp.api.FlagEvaluator;
import de.z0rdak.yawp.api.events.region.FlagCheckEvent;
import de.z0rdak.yawp.platform.Services;
import net.minecraft.class_1309;
import net.minecraft.class_1657;
import net.minecraft.class_1753;
import net.minecraft.class_1799;
import net.minecraft.class_1937;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfo;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfoReturnable;

import static de.z0rdak.yawp.api.MessageSender.sendFlagMsg;
import static de.z0rdak.yawp.core.flag.RegionFlag.FIRE_BOW;
import static de.z0rdak.yawp.handler.HandlerUtil.getDimKey;
import static de.z0rdak.yawp.handler.HandlerUtil.isServerSide;

@Mixin({class_1753.class})
public abstract class BowItemMixin {
    
    @Inject(method = "releaseUsing", at = @At(value = "INVOKE", target = "Lnet/minecraft/world/item/BowItem;getPowerForTime(I)F"), allow = 1, cancellable = true)
    void onLooseArrow(class_1799 stack, class_1937 level, class_1309 entityLiving, int timeLeft, CallbackInfoReturnable<Boolean> cir) {
        class_1657 player = (class_1657) entityLiving;
        if (isServerSide(player.method_37908())) {
            FlagCheckEvent checkEvent = new FlagCheckEvent(player.method_24515(), FIRE_BOW, getDimKey(player), player);
            if (Services.EVENT.post(checkEvent)) {
                return;
            }
            FlagEvaluator.processCheck(checkEvent, denyResult -> {
                cir.setReturnValue(false);
                sendFlagMsg(denyResult);
            });
        }
    }
}
